Sm2 class

Calculates SM-2 spaced repetition review intervals.

Sm2 is stateless. Store the returned Sm2Response values with your card or review item, then pass them back into calc on the next review.

Constructors

Sm2()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calc({required int quality, required int repetitions, required int previousInterval, required double previousEaseFactor}) Sm2Response
Calculates the next SM-2 state for one reviewed item.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited