Sm2Response class

Updated SM-2 state after one review.

Constructors

Sm2Response({required int interval, required int repetitions, required double easeFactor})
Creates an immutable SM-2 response.

Properties

easeFactor double
Updated ease factor, clamped to a minimum of 1.3.
final
hashCode int
The hash code for this object.
no setterinherited
interval int
Number of days until the next review.
final
repetitions int
Updated count of successful repetitions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited